<?php

/**
 * Plugin Name:       E2U AJAX Subscribe Newsletter
 * Plugin URI:        https://sajidztech.com
 * Description:       Here you can add this plugin in your wordPress website to get Subscribers email address. And those email aaddresses will show in your wordPress Admin Dashboard in a row of Table. You need to only paste the shortcode where you want to place this form.
 * Version:           1.0.0
 * Requires at least: 5.2
 * Requires PHP:      7.2
 * Author:            Mohammed Sajid Hasan
 * Author URI:        https://www.sajidztech.com
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       e2u-ajax-subscribe-newsletter
 * Domain Path:       /subscribe_newsletter
 */

if ( ! defined( 'ABSPATH' ) ) {
	$link = (__FILE__);
    echo "Don't try to come here by this <b>".$link."</b> Link";
    die;
}

class e2u_subscribe_newsletter {
	public function __construct (){
		add_action('init', array($this, 'e2u_subscribe_newsletter_list_db') );
		add_shortcode('e2u-subscribe-newsletter', array($this, 'e2u_subscribe_newsletter_shortcode') );
		add_action ('admin_menu', array($this, 'e2u_create_tab_in_dashboard') );
		add_action('admin_enqueue_scripts', array($this, 'e2u_enqueuing_in_dashboard'));
		add_action('wp_enqueue_scripts', array($this, 'e2u_enqueuing_in_newsletter'));
	}

	//Add scripts for Admin Dashboard
	public function e2u_enqueuing_in_dashboard(){
		wp_enqueue_style('e2u-custom-admin-css', PLUGINS_URL('/assets/e2u-custom-admin-css.css', __FILE__) );
		wp_enqueue_script('jquery-ui-tabs');
		wp_enqueue_script('e2u-custom-admin-js', PLUGINS_URL('/assets/e2u-custom-admin-js.js', __FILE__), array('jquery'), ' ', true);
	}
	
	//Add scripts for Newsletter in Page
	public function e2u_enqueuing_in_newsletter(){
		wp_enqueue_style('e2u-custom-newsletter-css', PLUGINS_URL('assets/e2u-custom-newsletter-css.css', __FILE__) );
		wp_enqueue_script('e2u-custom-newsletter-js', PLUGINS_URL('/e2u-custom-newsletter-js.js', __FILE__), array('jquery'), ' ', true);
	}

	//Create a Database when your Plugin is Activated
	public function e2u_subscribe_newsletter_list_db(){
		global $wpdb;
		//create database for subscriber list
		$createsubscriberslistdb = $wpdb->prefix. 'e2u_subscribe_newsletter_list';
		require_once(ABSPATH. 'wp-admin/includes/upgrade.php');
		dbDelta("CREATE TABLE $createsubscriberslistdb (subscribers_id INT NOT NULL AUTO_INCREMENT, subscribers_email_name varchar(250) NOT NULL, UNIQUE KEY id(subscribers_id) )");

		//create database for subscribe fields design
		$subscriberfielddesign = $wpdb->prefix. 'e2u_subscribe_field_design';
		require_once(ABSPATH. 'wp-admin/includes/upgrade.php');
		dbDelta("CREATE TABLE $subscriberfielddesign (e2u_design_id INT NOT NULL AUTO_INCREMENT, e2u_subscribe_form_tag varchar(255), email_field_classes varchar(255), email_field_placeholder varchar(255), submit_field_classes varchar(255), submit_field_labels varchar(255), UNIQUE KEY id(e2u_design_id) )");
		
	}

	//Email Subscribe Newsletter HTML Markup
	public function e2u_subscribe_newsletter_shortcode(){ ?>
		<?php
			global $wpdb;
			$subscriberfielddesign = $wpdb->prefix. 'e2u_subscribe_field_design';
			$form_tag = $wpdb->get_var($wpdb->prepare("SELECT e2u_subscribe_form_tag FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
			$email_field = $wpdb->get_var($wpdb->prepare("SELECT email_field_classes FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
			$email_placeholder = $wpdb->get_var($wpdb->prepare("SELECT email_field_placeholder FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
			$submit_field = $wpdb->get_var($wpdb->prepare("SELECT submit_field_classes FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
			$submit_labels = $wpdb->get_var($wpdb->prepare("SELECT submit_field_labels FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
		?>
		
		<div class="e2u-subscribers-form-wrapper">
			<form action="" method="POST" class="e2u-subscribe-form <?php echo $form_tag; ?>">
				<div class="disablingform"></div>
				<input type="email" name="e2u_subscribe_newsletter_email" id="e2u_subscribe_newsletter_email_field" class="<?php echo esc_attr($email_field); ?>" placeholder="<?php echo esc_attr($email_placeholder); ?>" required="required">
				<button type="submit" name="e2u_subscribe_newsletter_submit" id="e2u_subscribe_newsletter_submit" class="<?php echo esc_attr($submit_field); ?> e2u_subscribe_newsletter_submit_label"><?php echo esc_html($submit_labels); ?></button>
			</form>
			<div class="subscribe-success-msg">Thank You For Subscribing!</div>
		</div>
		<?php
		global $wpdb;
		if(!empty($_POST['e2u_subscribe_newsletter_email'])){
			$get_e2u_db = $wpdb->prefix. 'e2u_subscribe_newsletter_list';
		    $e2u_subecribe_email_address = sanitize_text_field($_POST['e2u_subscribe_newsletter_email']);
		    $wpdb->query($wpdb->prepare("INSERT INTO $get_e2u_db(subscribers_email_name ) VALUES(%s)", $e2u_subecribe_email_address));   
		};
		?>
		<script>
			(function($){
				jQuery('.e2u-subscribe-form').on('submit', function(){
					var e2usubscribeemailfield = jQuery('#e2u_subscribe_newsletter_email_field').val();
						jQuery(".disablingform").show();
						
					jQuery.ajax({
						'type' : 'POST',
						'data' : {
							'e2u_subscribe_newsletter_email' : e2usubscribeemailfield,
						},
						'success' : function(){
							jQuery('#e2u_subscribe_newsletter_email_field').val(' ');
							jQuery('.subscribe-success-msg').show();
							jQuery(".disablingform").hide();
						},
					});
					return false;
				});
			})(jQuery);
		</script>
	<?php }

	

	//Add a menu in your wordpress Dashboard
	public function e2u_create_tab_in_dashboard() {
		add_menu_page( 'E2U Subscribers List', 'E2U Subscribers List', 'manage_options', 'e2u_all_subscriber_list', array($this, 'e2u_all_subscriber_list'), 'dashicons-email-alt2', 60 );
	}

	//Add subscribers list in that E2U Subscribers List page in your wordpress dashboard
	public function e2u_all_subscriber_list() {
		if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ));
		} ?>
		<div id="e2u-dashboard-wrapper" class="e2u-dashboard-wrapper">
			<ul>
				<li><a href="#e2u-configure">Cunfiguration</a></li>
				<li><a href="#e2u-subscribers-lists">Subscribers Lists</a></li>
			</ul>
			<div id="e2u-configure">
				<div class="shortcode-add-wrapper">
					<label for="shortcode-add-label">Here you need to copy the marked shortcode and paste it where you want to use.</label>
					<input type="text" id="shortcode-add-label" value="[e2u-subscribe-newsletter]">
				</div>
				<div class="e2u-all-classes-content">
					<?php
						global $wpdb;
						if( isset( $_POST['classes_in_e2u_save'] ) ){
						    $get_e2u_newsletter_design_table = $wpdb->prefix. 'e2u_subscribe_field_design';

						    $classes_in_e2u_form_tag = sanitize_text_field($_POST['classes_in_e2u_form_tag']);
						    $classes_in_e2u_email_fields = sanitize_text_field($_POST['classes_in_e2u_email_fields']);
						    $classes_in_e2u_email_fields_placeholder = sanitize_text_field($_POST['classes_in_e2u_email_fields_placeholder']);
						    $classes_in_e2u_submmit_fields = sanitize_text_field($_POST['classes_in_e2u_submmit_fields']);
						    $classes_in_e2u_submmit_label = sanitize_text_field($_POST['classes_in_e2u_submmit_label']);
						    $wpdb->query($wpdb->prepare("INSERT INTO $get_e2u_newsletter_design_table(e2u_subscribe_form_tag, email_field_classes, email_field_placeholder, submit_field_classes, submit_field_labels ) VALUES(%s, %s, %s, %s, %s)", $classes_in_e2u_form_tag, $classes_in_e2u_email_fields,$classes_in_e2u_email_fields_placeholder, $classes_in_e2u_submmit_fields, $classes_in_e2u_submmit_label));           
						}
					?>
					<?php
					global $wpdb;
					$subscriberfielddesign = $wpdb->prefix. 'e2u_subscribe_field_design';
					$form_tag = $wpdb->get_var($wpdb->prepare("SELECT e2u_subscribe_form_tag FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
					$email_field = $wpdb->get_var($wpdb->prepare("SELECT email_field_classes FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
					$email_placeholder = $wpdb->get_var($wpdb->prepare("SELECT email_field_placeholder FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
					$submit_field = $wpdb->get_var($wpdb->prepare("SELECT submit_field_classes FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
					$submit_labels = $wpdb->get_var($wpdb->prepare("SELECT submit_field_labels FROM $subscriberfielddesign ORDER BY e2u_design_id DESC LIMIT 1"));
					?>
					<form action="" method="POST">
						<table>
							<tr>
								<td>
									<label for="classes_in_e2u_form_tag"><b>Add your specific classes in the Form Tag that you need to style in your CSS (if Have)</b></label>
								</td>
								<td>
									<input type="text" name="classes_in_e2u_form_tag" id="classes_in_e2u_form_tag" class="widefat" placeholder="add classes in Form Tag" value="<?php echo esc_html($form_tag); ?>">
								</td>
							</tr>
							<tr>
								<td>
									<label for="classes_in_e2u_email_fields"><b>Add your specific classes in the email field that you need to style in your CSS (if Have)</b></label>
								</td>
								<td>
									<input type="text" name="classes_in_e2u_email_fields" id="classes_in_e2u_email_fields" class="widefat" placeholder="add classes in Email Fields"  value="<?php echo esc_html($email_field); ?>">
								</td>
							</tr>
							
							<tr>
								<td>
									<label for="classes_in_e2u_email_fields_placeholder"><b>Add a placeholder in your email input field (if Have)</b></label>
								</td>
								<td>
									<input type="text" name="classes_in_e2u_email_fields_placeholder" id="classes_in_e2u_email_fields_placeholder" class="widefat" placeholder="add Email Fields Placeholder"  value="<?php echo esc_html($email_placeholder); ?>">
								</td>
							</tr>
							<tr>
								<td>
									<label for="classes_in_e2u_submmit_fields"><b>Add your specific classes in the Submit Button field that you need to in style your CSS (if Have)</b></label>
								</td>
								<td>
									<input type="text" name="classes_in_e2u_submmit_fields" id="classes_in_e2u_submmit_fields" class="widefat" placeholder="add classes in Submit Fields"  value="<?php echo esc_html($submit_field); ?>">
								</td>
							</tr>
							<tr>
								<td>
									<label for="classes_in_e2u_submmit_label"><b>Add your Submit Button Label</b></label>
								</td>
								<td>
									<input type="text" name="classes_in_e2u_submmit_label" id="classes_in_e2u_submmit_label" class="widefat" placeholder="add Submit Button Label"  value="<?php echo esc_html($submit_labels); ?>">
								</td>
							</tr>
							<tr>
								<td>
									<input type="submit" name="classes_in_e2u_save" class="classes_in_e2u_save" value="save">
								</td>
							</tr>
						</table>
					</form>
				</div>
			</div>
			<div id="e2u-subscribers-lists">
				<table class="e2u-subscribers-list">
					<tr>
						<th colspan="2">
							<h4>Your Subscribers Email Address</h4>
						</th>
					</tr>
					<tr>
						<th>ID No.</th>
						<th>Email Address</th>
					</tr>
					<?php
					global $wpdb;
					$get_e2u_db_retrivesr = $wpdb->prefix. 'e2u_subscribe_newsletter_list';
					$results = $wpdb->get_results('SELECT * FROM '.$get_e2u_db_retrivesr );
					foreach ( $results as $result ) : ?>
					<tr>
						<td><?php echo esc_html($result->subscribers_id); ?></td>
						<td><?php echo esc_html($result->subscribers_email_name); ?></td>
					</tr>
					<?php endforeach; ?>
				</table>
			</div>
		</div>
	<?php }
}

$e2u_subscribe_newsletter = new e2u_subscribe_newsletter();